package eu.mhsl.craftattack.spawn.chatMessages.listeners;

import eu.mhsl.craftattack.spawn.util.ConfigUtil;
import io.papermc.paper.event.player.AsyncChatEvent;
import net.kyori.adventure.text.Component;
import net.kyori.adventure.text.TextComponent;
import net.kyori.adventure.text.event.ClickEvent;
import net.kyori.adventure.text.format.TextColor;
import org.bukkit.Color;
import org.bukkit.entity.Player;
import org.bukkit.event.EventHandler;
import org.bukkit.event.Listener;
import org.bukkit.event.entity.PlayerDeathEvent;
import org.bukkit.event.player.PlayerJoinEvent;
import org.bukkit.event.player.PlayerQuitEvent;

import java.util.Objects;
import com.theokanning.openai.completion.CompletionRequest;
import com.theokanning.openai.service.OpenAiService;


public class PlayerChatListener implements Listener  {
    @EventHandler
    public void onPlayerChatEvent(AsyncChatEvent event) {
        event.renderer(
            (source, sourceDisplayName, message, viewer) -> Component.text("")
                    .append(sourceDisplayName.color(getPlayerColor(source)).clickEvent(ClickEvent.clickEvent(ClickEvent.Action.SUGGEST_COMMAND, "/report " + source.getName())))
                    .append(Component.text(" > ").color(TextColor.color(Color.GRAY.asRGB())))
                    .append(message).color(TextColor.color(Color.SILVER.asRGB())));

        if (ConfigUtil.getConfigUtil().isApiSwearWordCheck()) checkForSwearWord(((TextComponent) event.message()).content());
    }

    @EventHandler
    public void onPlayerJoin(PlayerJoinEvent event) {
        event.joinMessage(
            Component.text("")
                .append(Component.text("↑ ").color(TextColor.color(Color.GREEN.asRGB())))
                .append(Component.text(event.getPlayer().getName()).color(getPlayerColor(event.getPlayer())))
        );

    }

    @EventHandler
    public void onPlayerLeave(PlayerQuitEvent event) {
        event.quitMessage(
            Component.text("")
                .append(Component.text("↓ ").color(TextColor.fromCSSHexString("#8C0012")))
                .append(Component.text(event.getPlayer().getName()).color(getPlayerColor(event.getPlayer())))
        );
    }

    @EventHandler
    public void onDeath(PlayerDeathEvent event) {
        event.deathMessage(Component.text("☠ ").append(Objects.requireNonNull(event.deathMessage()).color(TextColor.color(Color.SILVER.asRGB()))));
    }

    private TextColor getPlayerColor(Player player) {
        if (player.hasPermission("chatcolor")) return TextColor.color(Color.AQUA.asRGB());
        return TextColor.color(Color.WHITE.asRGB());
    }


    private boolean checkForSwearWord(String msg) {
        String token = ConfigUtil.getConfigUtil().getApiToken();
        OpenAiService service = new OpenAiService(token);

        CompletionRequest completionRequest = CompletionRequest.builder()
                .prompt("Does \"" + msg + "\" contain a swear word or ist it maybe insulting to another player? Only answer with true of false!")
                .model("text-davinci-003")
                .temperature(0D)
                .maxTokens(4)
                .topP(1D)
                .frequencyPenalty(0.5D)
                .presencePenalty(0D)
                .bestOf(1)
                .build();
        System.out.println(service.createCompletion(completionRequest).getChoices().get(0).getText());
        // Report if necessary is needed
        return  false;
    }
}
